﻿B4i=true
Group=Default Group
ModulesStructureVersion=1
Type=StaticCode
Version=5
@EndOfDesignText@
'************************************************************************************
'
'This procedure only available in main/code modules - not class
'
'Variables declared here are "process variables" or "app variables" ("process" = 
'"app instance", i.e. copy of app running in memory) that are global to process, 
'meaning:
'    
'   o Declared once when app instance starts and live as long as app instance 
'     lives(*) - this sub is called once when app instance starts (this is true for
'     all code modules, not just Main module)
'   o Public: can be accessed from all procedures in all modules in app (including 
'     classes), referenced as publicvariablename in this module and as
'     thismodulename.publicvariablename in other modules
'   o Private: can be accessed from all procedures of this module - referenced as 
'     privatevariablename
'   o Retain their state and content for life of app instance(*) 
'   o Initialization of any objects declared here can be done in any sub of any
'     code module of app
'   o Initialization of any objects declared here would NORMALLY BE DONE ONCE for
'     life of app instance(*), i.e.:
'       o In Main module (typically Application_Start sub)
'       o Anywhere in any module when prefaced with
'           [If Not(thismodulename.publicvariablename.IsIntialized) Then ...]
'   o Not all types of objects can be declared as app variables e.g. all views 
'     cannot be declared as app variables because we do not want to hold a 
'     reference to objects that should be destroyed together with views parent page
'
'(*) life of app instance = from Application_Start to Application_Background followed
'    by app instance destruction (i.e. removal from memory)
'
'************************************************************************************
Sub Process_Globals

	Public Videoplayer_page As Page
	Private UI_navigation_back As Label
	Private UI_videoplayer As VideoPlayer

End Sub

'************************************************************************************
'
'This procedure gets control when Open method is called by parent module
'
'Input parameters are:
'
'       None
'
'Returns:
'
'       -
'
'Notes on this procedure:
'
'       o None
'
'************************************************************************************
Public Sub Open

	'Hide status bar, see:
	'https://www.b4x.com/android/forum/threads/full-screen-apps.47866/#content
	Private wrk_no As NativeObject = Main.App
	wrk_no.RunMethod("setStatusBarHidden:animated:", Array(True, False))
	
	'Initialize Videoplayer_page
	Videoplayer_page.Initialize("Event_videoplayer_page")

	'This will fire Event_videoplayer_page_Appear then Event_videoplayer_page_Resize
	Main.NavControl.ShowPage2(Videoplayer_page, False)
	
End Sub

'************************************************************************************
'
'This procedure gets control when Videoplayer_page appears/reappears
'
'Input parameters are:
'
'       None
'
'Returns:
'
'       -
'
'Notes on this procedure:
'
'       o None
'
'************************************************************************************
Private Sub Event_videoplayer_page_Appear

End Sub

'************************************************************************************
'
'This procedure gets control when Videoplayer_page disappears
'
'Input parameters are:
'
'       None
'
'Returns:
'
'       -
'
'Notes on this procedure:
'
'       o None
'
'************************************************************************************
Private Sub Event_videoplayer_page_Disappear
	
	'Pause video player (doesn't seem to be a stop capability)
	UI_videoplayer.Pause

End Sub

'************************************************************************************
'
'This procedure gets control when Videoplayer_page is shown 
'(Main.NavControl.ShowPage2(Videoplayer_page, False)) or is resized (phone 
'orientation changes or Navigation/Tool/Status bars change visibility state)
'
'Input parameters are:
'
'       Width, Height = page dimensions
'
'Returns:
'
'       -
'
'Notes on this procedure:
'
'       o None
'
'************************************************************************************
Private Sub Event_videoplayer_page_Resize(Width As Int, Height As Int)
	
	'Pause video player (doesn't seem to be a stop capability)
	UI_videoplayer.Pause

	'Clean up
	Videoplayer_page.RootPanel.RemoveAllViews

	'Set up app background
	Videoplayer_page.RootPanel.Color = Colors.White

	'UI_videoplayer is defined and initialized in videoplayerlayout
	Videoplayer_page.RootPanel.LoadLayout("videoplayerlayout")

	'Set up UI_videoplayer custom view
	UI_videoplayer.BaseView.Top = 0
	UI_videoplayer.BaseView.Left = 0
	UI_videoplayer.BaseView.Width = Videoplayer_page.RootPanel.Width
	UI_videoplayer.BaseView.Height = Videoplayer_page.RootPanel.Height

	'Set up video source
	UI_videoplayer.LoadVideoUrl("https://d2f6wi46nh6lwa.cloudfront.net/help-mn.mp4")
	
	'Wait for video to load
	Wait For Event_UI_videoplayer_Ready(Success As Boolean)
	
	'Set up navigation back
	UI_navigation_back.Initialize("Event_back")
	Videoplayer_page.RootPanel.AddView(UI_navigation_back, 0, 0, Videoplayer_page.RootPanel.Width, Videoplayer_page.RootPanel.Height)
	UI_navigation_back.Text = "< Back "
	UI_navigation_back.TextAlignment = UI_navigation_back.ALIGNMENT_LEFT
	UI_navigation_back.Font = Font.CreateNew2(Font.DEFAULT.Name, .03 * Max(Videoplayer_page.RootPanel.Height, Videoplayer_page.RootPanel.Width))
	UI_navigation_back.Color = Colors.white
	UI_navigation_back.TextColor = Colors.Black
	UI_navigation_back.Visible = True
	UI_navigation_back.SizeToFit
	
	'If successfully loaded, play it
	If Success Then	UI_videoplayer.Play

End Sub

'************************************************************************************
'
'This procedure gets control when < Back navigation button is clicked
' 
'Input parameters are:
'
'       None
'
'Returns:
'
'       -
'
'Notes on this procedure:
'
'       o None
'
'************************************************************************************
Private Sub Event_back_Click
	
	'Pause video player (doesn't seem to be a stop capability)
	UI_videoplayer.Pause

	'Clean up
	Videoplayer_page.RootPanel.RemoveAllViews

	'Show status bar, see:
	'https://www.b4x.com/android/forum/threads/full-screen-apps.47866/#content
	Private wrk_no As NativeObject = Main.App
	wrk_no.RunMethod("setStatusBarHidden:animated:", Array(False, False))

	'Return to previous page
	Main.NavControl.RemoveCurrentPage

End Sub

'************************************************************************************
'
'This procedure gets control when video finishes
' 
'Input parameters are:
'
'       None
'
'Returns:
'
'       -
'
'Notes on this procedure:
'
'       o None
'
'************************************************************************************
Private Sub Event_UI_videoplayer_Complete

	'Clean up
	Videoplayer_page.RootPanel.RemoveAllViews

	'Show status bar, see:
	'https://www.b4x.com/android/forum/threads/full-screen-apps.47866/#content
	Private wrk_no As NativeObject = Main.App
	wrk_no.RunMethod("setStatusBarHidden:animated:", Array(False, False))
	
	'Return to previous page
	Main.NavControl.RemoveCurrentPage
	
End Sub
